==> woocommerce-rtm-custom-emails.1.3.1.zip: templates/emails/customer-bank-reminder.php <==
<?php

/**
 * Customer invoice email
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/customer-invoice.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates/Emails
 * @version     2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email ); ?>

<?php
$first_name = $order->get_billing_first_name();
$at = get_bloginfo( 'name', 'display' );
$payment_link = '<a href="' . esc_url( $order->get_checkout_payment_url() ) . '">this link</a>';

$email_text = <<<HTML
<p>Hello $first_name,</p>
<p>You are registered for a Dutch course at Taalthuis. However, you have not yet paid for the course. Can you make the payment so we can make your registration official?.</p>
<p>Below you can find the details of the course you are registered for. </p>
<p>Thank you in advance and enjoy learning Dutch at Taalthuis! </p>
HTML;

echo $email_text;

/**
 * @hooked WC_Emails::order_details() Shows the order details table.
 * @hooked WC_Structured_Data::generate_order_data() Generates structured data.
 * @hooked WC_Structured_Data::output_structured_data() Outputs structured data.
 * @since 2.5.0
 */
do_action( 'woocommerce_email_order_details', $order, $sent_to_admin, $plain_text, $email );

/**
 * @hooked WC_Emails::customer_details() Shows customer details
 * @hooked WC_Emails::email_address() Shows email address
 */
do_action( 'woocommerce_email_customer_details', $order, $sent_to_admin, $plain_text, $email );

/**
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );

==> woocommerce-rtm-custom-emails.1.3.2.zip: templates/emails/customer-bank-reminder.php <==
<?php

/**
 * Customer invoice email
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/customer-invoice.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates/Emails
 * @version     2.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @hooked WC_Emails::email_header() Output the email header
 */
do_action( 'woocommerce_email_header', $email_heading, $email ); ?>

<?php
$first_name = $order->get_billing_first_name();
$at = get_bloginfo( 'name', 'display' );
$payment_link = '<a href="' . esc_url( $order->get_checkout_payment_url() ) . '">this link</a>';

$email_text = <<<HTML
<p>Dear $first_name,</p>
<p>You are registered for a Dutch course at Taalthuis. However, you have not yet paid for the course. Can you make the payment so we can make your registration official?.</p>
<p>Below you can find the details of the course you are registered for. </p>
<p>Thank you in advance and enjoy learning Dutch at Taalthuis! </p>
HTML;

echo $email_text;

/**
 * @hooked WC_Emails::order_details() Shows the order details table.
 * @hooked WC_Structured_Data::generate_order_data() Generates structured data.
 * @hooked WC_Structured_Data::output_structured_data() Outputs structured data.
 * @since 2.5.0
 */
do_action( 'woocommerce_email_order_details', $order, $sent_to_admin, $plain_text, $email );

/**
 * @hooked WC_Emails::customer_details() Shows customer details
 * @hooked WC_Emails::email_address() Shows email address
 */
do_action( 'woocommerce_email_customer_details', $order, $sent_to_admin, $plain_text, $email );

/**
 * @hooked WC_Emails::email_footer() Output the email footer
 */
do_action( 'woocommerce_email_footer', $email );
